<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:i6="http://iuclid6.echa.europa.eu/namespaces/platform-fields/v1" xmlns:i6c="http://iuclid6.echa.europa.eu/namespaces/platform-container/v1" xmlns:xt="http://iuclid6.echa.europa.eu/namespaces/FLEXIBLE_RECORD-SubstanceComposition/3.0" version="1.0">
    <xsl:template match="/">
        <html>
            <head>
                <link href="iuclid6_style.css" rel="stylesheet" type="text/css"/>
            </head>
            <body>
                <table>
                    <tr/>
                    <xsl:apply-templates/>
                </table>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="//i6c:PlatformMetadata | //i6c:Attachments | //i6c:ModificationHistory"/>
    <xsl:template match="//xt:FLEXIBLE_RECORD">
        <tr class="headerDocument">
            <td>Composition</td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:RelevantForClassificationLabeling | //xt:RelevantForClassificationLabeling">
        <tr>
            <td class="label">This additive is considered relevant for the classification and labelling of the substance</td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:DataProtection | //xt:DataProtection | //xt:DataProtection | //xt:DataProtection | //xt:DataProtection">
        <tr>
            <td class="label"/>
            <td class="value">
                <xsl:apply-templates/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:ReferenceSubstance | //xt:ReferenceSubstance | //xt:ReferenceSubstance | //xt:SurfaceTreatmentAgent">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'ReferenceSubstance'">Reference substance</xsl:when>
                    <xsl:when test="name(.) = 'SurfaceTreatmentAgent'">Surface treatment agent</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:Purity | //xt:ProportionTypical | //xt:Concentration | //xt:ProportionTypical | //xt:Concentration | //xt:ProportionTypical | //xt:Concentration | //xt:XDimension | //xt:YDimension | //xt:ZDimension | //xt:SpecificSurfaceArea | //xt:TotalFractionCoreParticleWW">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'TotalFractionCoreParticleWW'">Total fraction  core particle, % (w/w)</xsl:when>
                    <xsl:when test="name(.) = 'XDimension'">x Dimension</xsl:when>
                    <xsl:when test="name(.) = 'ZDimension'">z Dimension</xsl:when>
                    <xsl:when test="name(.) = 'ProportionTypical'">Typical concentration</xsl:when>
                    <xsl:when test="name(.) = 'SpecificSurfaceArea'">Specific surface area</xsl:when>
                    <xsl:when test="name(.) = 'Purity'"/>
                    <xsl:when test="name(.) = 'YDimension'">y Dimension</xsl:when>
                    <xsl:when test="name(.) = 'Concentration'">Concentration range</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select="./i6:lowerQualifier "/>
                <xsl:value-of select="./i6:lowerValue "/>
                <xsl:value-of select="./i6:upperQualifier "/>
                <xsl:value-of select="./i6:upperValue "/>
                <xsl:choose>
                    <xsl:when test="./i6:unitCode = '2505'"> % (w/w)</xsl:when>
                    <xsl:when test="./i6:unitCode = '2506'"> % (v/v)</xsl:when>
                    <xsl:when test="./i6:unitCode = '2098'"> mg/L</xsl:when>
                    <xsl:when test="./i6:unitCode = '3437'"> mg/kg</xsl:when>
                    <xsl:when test="./i6:unitCode = '2283'"> ppm</xsl:when>
                    <xsl:when test="./i6:unitCode = '3440'"> mg/m³</xsl:when>
                    <xsl:when test="./i6:unitCode = '58237'"> nm</xsl:when>
                    <xsl:when test="./i6:unitCode = '58238'"> μm</xsl:when>
                    <xsl:when test="./i6:unitCode = '58239'"> mm</xsl:when>
                    <xsl:when test="./i6:unitCode = '1342'"> other:</xsl:when>
                    <xsl:when test="./i6:unitCode = '58282'"> m²/g</xsl:when>
                    <xsl:when test="./i6:unitCode = '58283'"> m²/cm³</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:unitOther "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:TypeOfComposition | //xt:StateForm | //xt:Function | //xt:Shape | //xt:Percentile | //xt:SurfaceTreatmentApplied | //xt:Layer | //xt:ExternalLayer">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'Function'">Function</xsl:when>
                    <xsl:when test="name(.) = 'StateForm'">State / form</xsl:when>
                    <xsl:when test="name(.) = 'Percentile'">Percentile</xsl:when>
                    <xsl:when test="name(.) = 'Shape'">Shape</xsl:when>
                    <xsl:when test="name(.) = 'TypeOfComposition'">Type of composition</xsl:when>
                    <xsl:when test="name(.) = 'ExternalLayer'">External layer</xsl:when>
                    <xsl:when test="name(.) = 'SurfaceTreatmentApplied'">Surface treatment applied</xsl:when>
                    <xsl:when test="name(.) = 'Layer'">Layer</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:choose>
                    <xsl:when test="./i6:value = '61423'">legal entity composition of the substance</xsl:when>
                    <xsl:when test="./i6:value = '61421'">boundary composition of the substance</xsl:when>
                    <xsl:when test="./i6:value = '61422'">composition of the substance generated upon use</xsl:when>
                    <xsl:when test="./i6:value = '1342'">other:</xsl:when>
                    <xsl:when test="./i6:value = '2830'">gas</xsl:when>
                    <xsl:when test="./i6:value = '2038'">liquid</xsl:when>
                    <xsl:when test="./i6:value = '61424'">solid: bulk</xsl:when>
                    <xsl:when test="./i6:value = '60053'">solid: fibres</xsl:when>
                    <xsl:when test="./i6:value = '60059'">solid: nanomaterial</xsl:when>
                    <xsl:when test="./i6:value = '60058'">solid: particulate/powder</xsl:when>
                    <xsl:when test="./i6:value = '2675'">absorbent</xsl:when>
                    <xsl:when test="./i6:value = '2680'">adsorbent</xsl:when>
                    <xsl:when test="./i6:value = '2693'">anticaking agent</xsl:when>
                    <xsl:when test="./i6:value = '2694'">anticoagulant</xsl:when>
                    <xsl:when test="./i6:value = '2721'">booster</xsl:when>
                    <xsl:when test="./i6:value = '2728'">buffer</xsl:when>
                    <xsl:when test="./i6:value = '2752'">coagulant</xsl:when>
                    <xsl:when test="./i6:value = '2753'">coating agent</xsl:when>
                    <xsl:when test="./i6:value = '2756'">colourant</xsl:when>
                    <xsl:when test="./i6:value = '2761'">complexing agent</xsl:when>
                    <xsl:when test="./i6:value = '2763'">conditioner</xsl:when>
                    <xsl:when test="./i6:value = '2768'">controlled release agent</xsl:when>
                    <xsl:when test="./i6:value = '2772'">crystal growth regulator</xsl:when>
                    <xsl:when test="./i6:value = '2781'">dehydrating agent</xsl:when>
                    <xsl:when test="./i6:value = '2783'">denaturant</xsl:when>
                    <xsl:when test="./i6:value = '2794'">drying agent</xsl:when>
                    <xsl:when test="./i6:value = '2795'">dye</xsl:when>
                    <xsl:when test="./i6:value = '2802'">emulsifier</xsl:when>
                    <xsl:when test="./i6:value = '2819'">filler</xsl:when>
                    <xsl:when test="./i6:value = '2823'">flow aid agent</xsl:when>
                    <xsl:when test="./i6:value = '2824'">fragrance</xsl:when>
                    <xsl:when test="./i6:value = '2847'">hardener</xsl:when>
                    <xsl:when test="./i6:value = '2895'">lubricant</xsl:when>
                    <xsl:when test="./i6:value = '2918'">moisturiser</xsl:when>
                    <xsl:when test="./i6:value = '2937'">neutraliser</xsl:when>
                    <xsl:when test="./i6:value = '2976'">odour masking agent</xsl:when>
                    <xsl:when test="./i6:value = '3442'">pH adjuster</xsl:when>
                    <xsl:when test="./i6:value = '2999'">pigment</xsl:when>
                    <xsl:when test="./i6:value = '3026'">propellant</xsl:when>
                    <xsl:when test="./i6:value = '3342'">solvent</xsl:when>
                    <xsl:when test="./i6:value = '61432'">stabiliser: antioxidant</xsl:when>
                    <xsl:when test="./i6:value = '61433'">stabiliser: inhibitor</xsl:when>
                    <xsl:when test="./i6:value = '61434'">stabiliser: UV absorber</xsl:when>
                    <xsl:when test="./i6:value = '61435'">stabiliser: other</xsl:when>
                    <xsl:when test="./i6:value = '3350'">stiffener</xsl:when>
                    <xsl:when test="./i6:value = '3400'">UV absorber</xsl:when>
                    <xsl:when test="./i6:value = '3424'">viscosity modifier</xsl:when>
                    <xsl:when test="./i6:value = '3426'">water repellent</xsl:when>
                    <xsl:when test="./i6:value = '3429'">wetting agent</xsl:when>
                    <xsl:when test="./i6:value = '62249'">nanofiber</xsl:when>
                    <xsl:when test="./i6:value = '62250'">nanoparticle</xsl:when>
                    <xsl:when test="./i6:value = '62251'">nanoplate</xsl:when>
                    <xsl:when test="./i6:value = '308'">D10</xsl:when>
                    <xsl:when test="./i6:value = '60199'">D25</xsl:when>
                    <xsl:when test="./i6:value = '309'">D50</xsl:when>
                    <xsl:when test="./i6:value = '60200'">D75</xsl:when>
                    <xsl:when test="./i6:value = '310'">D90</xsl:when>
                    <xsl:when test="./i6:value = '119'">D95</xsl:when>
                    <xsl:when test="./i6:value = '120'">D99</xsl:when>
                    <xsl:when test="./i6:value = '4830'">none</xsl:when>
                    <xsl:when test="./i6:value = '58295'">coating</xsl:when>
                    <xsl:when test="./i6:value = '58296'">functionalisation</xsl:when>
                    <xsl:when test="./i6:value = '61426'">functionalisation and coating</xsl:when>
                    <xsl:when test="./i6:value = '2'">#1</xsl:when>
                    <xsl:when test="./i6:value = '4'">#2</xsl:when>
                    <xsl:when test="./i6:value = '5'">#3</xsl:when>
                    <xsl:when test="./i6:value = '6'">#4</xsl:when>
                    <xsl:when test="./i6:value = '7'">#5</xsl:when>
                    <xsl:when test="./i6:value = '8'">#6</xsl:when>
                    <xsl:when test="./i6:value = '9'">#7</xsl:when>
                    <xsl:when test="./i6:value = '10'">#8</xsl:when>
                    <xsl:when test="./i6:value = '11'">#9</xsl:when>
                    <xsl:when test="./i6:value = '3'">#10</xsl:when>
                    <xsl:when test="./i6:value = '4070'">#11</xsl:when>
                    <xsl:when test="./i6:value = '4071'">#12</xsl:when>
                    <xsl:when test="./i6:value = '4072'">#13</xsl:when>
                    <xsl:when test="./i6:value = '4073'">#14</xsl:when>
                    <xsl:when test="./i6:value = '4074'">#15</xsl:when>
                    <xsl:when test="./i6:value = '4075'">#16</xsl:when>
                    <xsl:when test="./i6:value = '4076'">#17</xsl:when>
                    <xsl:when test="./i6:value = '4077'">#18</xsl:when>
                    <xsl:when test="./i6:value = '4078'">#19</xsl:when>
                    <xsl:when test="./i6:value = '4079'">#20</xsl:when>
                    <xsl:when test="./i6:value = '61427'">hydrophilic</xsl:when>
                    <xsl:when test="./i6:value = '61428'">hydrophobic</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:other "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:AttachedDescription | //xt:Constituents | //xt:Impurities | //xt:Additives | //xt:repeatableSet8912 | //xt:SurfaceTreatment | //xt:SupportingInformation">
        <tr class="headerBlock">
            <td>
                <xsl:choose>
                    <xsl:when test="name(.) = 'Constituents'"/>
                    <xsl:when test="name(.) = 'Additives'"/>
                    <xsl:when test="name(.) = 'Impurities'"/>
                    <xsl:when test="name(.) = 'repeatableSet8912'"/>
                    <xsl:when test="name(.) = 'SurfaceTreatment'">Surface treatment</xsl:when>
                    <xsl:when test="name(.) = 'SupportingInformation'">Supporting information</xsl:when>
                    <xsl:when test="name(.) = 'AttachedDescription'">Attached description</xsl:when>
                </xsl:choose>
            </td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:GeneralInformation | //xt:RelatedCompositions | //xt:DegreeOfPurity | //xt:Constituents | //xt:Impurities | //xt:Additives | //xt:CharacterisationOfNanomaterials | //xt:ShapeAndParticleSizeRange | //xt:SpecificSurfaceArea | //xt:SurfaceTreatment">
        <tr class="headerBlock">
            <td>
                <xsl:choose>
                    <xsl:when test="name(.) = 'Constituents'">Constituents</xsl:when>
                    <xsl:when test="name(.) = 'Additives'">Additives</xsl:when>
                    <xsl:when test="name(.) = 'DegreeOfPurity'">Degree of purity</xsl:when>
                    <xsl:when test="name(.) = 'CharacterisationOfNanomaterials'">Characterisation of nanomaterials</xsl:when>
                    <xsl:when test="name(.) = 'Impurities'">Impurities</xsl:when>
                    <xsl:when test="name(.) = 'SpecificSurfaceArea'">Specific surface area</xsl:when>
                    <xsl:when test="name(.) = 'GeneralInformation'">General Information</xsl:when>
                    <xsl:when test="name(.) = 'SurfaceTreatment'">Surface treatment</xsl:when>
                    <xsl:when test="name(.) = 'RelatedCompositions'">Related composition(s)</xsl:when>
                    <xsl:when test="name(.) = 'ShapeAndParticleSizeRange'">Shape and particle size range</xsl:when>
                </xsl:choose>
            </td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:Name | //xt:DescriptionOfComposition | //xt:Remarks | //xt:JustificationForDeviations | //xt:ReferenceToRelatedCompositions | //xt:Remarks | //xt:Remarks | //xt:DetailsOfFunctionInComposition | //xt:Remarks | //xt:Remarks | //xt:Remarks | //xt:SurfaceTreatmentName | //xt:Remarks | //xt:Remarks | //xt:Remarks">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'DescriptionOfComposition'">Description</xsl:when>
                    <xsl:when test="name(.) = 'ReferenceToRelatedCompositions'">Reference to related composition(s)</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDeviations'">Justification for deviations</xsl:when>
                    <xsl:when test="name(.) = 'DetailsOfFunctionInComposition'">Details of function in composition</xsl:when>
                    <xsl:when test="name(.) = 'Remarks'">Remarks</xsl:when>
                    <xsl:when test="name(.) = 'SurfaceTreatmentName'">Surface treatment name</xsl:when>
                    <xsl:when test="name(.) = 'Name'">Name</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//i6:country/i6:value">
        <xsl:choose>
            <xsl:when test=". = '3446'">Åland Islands </xsl:when>
            <xsl:when test=". = '2683'">Afghanistan </xsl:when>
            <xsl:when test=". = '2684'">Albania </xsl:when>
            <xsl:when test=". = '2685'">Algeria </xsl:when>
            <xsl:when test=". = '2686'">American Samoa </xsl:when>
            <xsl:when test=". = '2688'">Andorra </xsl:when>
            <xsl:when test=". = '2689'">Angola </xsl:when>
            <xsl:when test=". = '2690'">Anguilla </xsl:when>
            <xsl:when test=". = '2692'">Antarctica </xsl:when>
            <xsl:when test=". = '2695'">Antigua and Barbuda </xsl:when>
            <xsl:when test=". = '2696'">Argentina </xsl:when>
            <xsl:when test=". = '2697'">Armenia </xsl:when>
            <xsl:when test=". = '2698'">Aruba </xsl:when>
            <xsl:when test=". = '107'">Australia </xsl:when>
            <xsl:when test=". = '108'">Austria </xsl:when>
            <xsl:when test=". = '2701'">Azerbaijan </xsl:when>
            <xsl:when test=". = '2702'">Bahamas </xsl:when>
            <xsl:when test=". = '2703'">Bahrain </xsl:when>
            <xsl:when test=". = '2704'">Bangladesh </xsl:when>
            <xsl:when test=". = '2705'">Barbados </xsl:when>
            <xsl:when test=". = '2707'">Belarus </xsl:when>
            <xsl:when test=". = '147'">Belgium </xsl:when>
            <xsl:when test=". = '2708'">Belize </xsl:when>
            <xsl:when test=". = '2709'">Benin </xsl:when>
            <xsl:when test=". = '2710'">Bermuda </xsl:when>
            <xsl:when test=". = '2711'">Bhutan </xsl:when>
            <xsl:when test=". = '2720'">Bolivia, Plurinational State of </xsl:when>
            <xsl:when test=". = '2722'">Bosnia and Herzegovina </xsl:when>
            <xsl:when test=". = '2723'">Botswana </xsl:when>
            <xsl:when test=". = '2724'">Bouvet Island </xsl:when>
            <xsl:when test=". = '2725'">Brazil </xsl:when>
            <xsl:when test=". = '2726'">British Indian Ocean Territory </xsl:when>
            <xsl:when test=". = '2727'">Brunei Darussalam </xsl:when>
            <xsl:when test=". = '184'">Bulgaria </xsl:when>
            <xsl:when test=". = '2729'">Burkina Faso </xsl:when>
            <xsl:when test=". = '2730'">Burundi </xsl:when>
            <xsl:when test=". = '2734'">Cambodia </xsl:when>
            <xsl:when test=". = '2735'">Cameroon </xsl:when>
            <xsl:when test=". = '206'">Canada </xsl:when>
            <xsl:when test=". = '2736'">Cape Verde </xsl:when>
            <xsl:when test=". = '2746'">Cayman Islands </xsl:when>
            <xsl:when test=". = '2747'">Central African Republic </xsl:when>
            <xsl:when test=". = '2748'">Chad </xsl:when>
            <xsl:when test=". = '2749'">Chile </xsl:when>
            <xsl:when test=". = '2750'">China </xsl:when>
            <xsl:when test=". = '2751'">Christmas Island </xsl:when>
            <xsl:when test=". = '2754'">Cocos (Keeling) Islands </xsl:when>
            <xsl:when test=". = '2755'">Colombia </xsl:when>
            <xsl:when test=". = '2759'">Comoros </xsl:when>
            <xsl:when test=". = '2764'">Congo </xsl:when>
            <xsl:when test=". = '2765'">Congo, The Democratic Republic of the </xsl:when>
            <xsl:when test=". = '2769'">Cook Islands </xsl:when>
            <xsl:when test=". = '2771'">Costa Rica </xsl:when>
            <xsl:when test=". = '286'">Croatia </xsl:when>
            <xsl:when test=". = '2774'">Côte d'Ivoire </xsl:when>
            <xsl:when test=". = '2773'">Cuba </xsl:when>
            <xsl:when test=". = '304'">Cyprus </xsl:when>
            <xsl:when test=". = '307'">Czech Republic </xsl:when>
            <xsl:when test=". = '333'">Denmark </xsl:when>
            <xsl:when test=". = '2790'">Djibouti </xsl:when>
            <xsl:when test=". = '2791'">Dominica </xsl:when>
            <xsl:when test=". = '2792'">Dominican Republic </xsl:when>
            <xsl:when test=". = '2799'">Ecuador </xsl:when>
            <xsl:when test=". = '2800'">Egypt </xsl:when>
            <xsl:when test=". = '2801'">El Salvador </xsl:when>
            <xsl:when test=". = '2803'">Equatorial Guinea </xsl:when>
            <xsl:when test=". = '2804'">Eritrea </xsl:when>
            <xsl:when test=". = '754'">Estonia </xsl:when>
            <xsl:when test=". = '2805'">Ethiopia </xsl:when>
            <xsl:when test=". = '2813'">Falkland Islands (Malvinas) </xsl:when>
            <xsl:when test=". = '2815'">Faroe Islands </xsl:when>
            <xsl:when test=". = '2817'">Fiji </xsl:when>
            <xsl:when test=". = '766'">Finland </xsl:when>
            <xsl:when test=". = '779'">France </xsl:when>
            <xsl:when test=". = '2825'">French Guiana </xsl:when>
            <xsl:when test=". = '2826'">French Polynesia </xsl:when>
            <xsl:when test=". = '2827'">French Southern Territories </xsl:when>
            <xsl:when test=". = '2828'">Gabon </xsl:when>
            <xsl:when test=". = '2829'">Gambia </xsl:when>
            <xsl:when test=". = '2834'">Georgia </xsl:when>
            <xsl:when test=". = '807'">Germany </xsl:when>
            <xsl:when test=". = '2835'">Ghana </xsl:when>
            <xsl:when test=". = '2836'">Gibraltar </xsl:when>
            <xsl:when test=". = '810'">Greece </xsl:when>
            <xsl:when test=". = '2838'">Greenland </xsl:when>
            <xsl:when test=". = '2839'">Grenada </xsl:when>
            <xsl:when test=". = '2840'">Guadeloupe </xsl:when>
            <xsl:when test=". = '2841'">Guam </xsl:when>
            <xsl:when test=". = '2842'">Guatemala </xsl:when>
            <xsl:when test=". = '7818'">Guernsey </xsl:when>
            <xsl:when test=". = '2843'">Guinea </xsl:when>
            <xsl:when test=". = '2844'">Guinea-Bissau </xsl:when>
            <xsl:when test=". = '2845'">Guyana </xsl:when>
            <xsl:when test=". = '2846'">Haiti </xsl:when>
            <xsl:when test=". = '2851'">Heard Island and McDonald Islands </xsl:when>
            <xsl:when test=". = '2854'">Holy See (Vatican City State) </xsl:when>
            <xsl:when test=". = '2855'">Honduras </xsl:when>
            <xsl:when test=". = '2856'">Hong Kong </xsl:when>
            <xsl:when test=". = '845'">Hungary </xsl:when>
            <xsl:when test=". = '882'">Iceland </xsl:when>
            <xsl:when test=". = '2865'">India </xsl:when>
            <xsl:when test=". = '2866'">Indonesia </xsl:when>
            <xsl:when test=". = '2870'">Iran, Islamic Republic of </xsl:when>
            <xsl:when test=". = '2871'">Iraq </xsl:when>
            <xsl:when test=". = '911'">Ireland </xsl:when>
            <xsl:when test=". = '7819'">Isle of man </xsl:when>
            <xsl:when test=". = '2876'">Israel </xsl:when>
            <xsl:when test=". = '916'">Italy </xsl:when>
            <xsl:when test=". = '2877'">Jamaica </xsl:when>
            <xsl:when test=". = '918'">Japan </xsl:when>
            <xsl:when test=". = '7820'">Jersey </xsl:when>
            <xsl:when test=". = '2878'">Jordan </xsl:when>
            <xsl:when test=". = '2879'">Kazakhstan </xsl:when>
            <xsl:when test=". = '2880'">Kenya </xsl:when>
            <xsl:when test=". = '2881'">Kiribati </xsl:when>
            <xsl:when test=". = '2882'">Korea, Democratic People's Republic of </xsl:when>
            <xsl:when test=". = '2883'">Korea, Republic Of </xsl:when>
            <xsl:when test=". = '2884'">Kuwait </xsl:when>
            <xsl:when test=". = '2885'">Kyrgyzstan </xsl:when>
            <xsl:when test=". = '2886'">Lao People's Democratic Republic </xsl:when>
            <xsl:when test=". = '985'">Latvia </xsl:when>
            <xsl:when test=". = '2887'">Lebanon </xsl:when>
            <xsl:when test=". = '2888'">Lesotho </xsl:when>
            <xsl:when test=". = '2889'">Liberia </xsl:when>
            <xsl:when test=". = '2890'">Libyan Arab Jamahiriya </xsl:when>
            <xsl:when test=". = '2891'">Liechtenstein </xsl:when>
            <xsl:when test=". = '1024'">Lithuania </xsl:when>
            <xsl:when test=". = '1041'">Luxembourg </xsl:when>
            <xsl:when test=". = '2896'">Macao </xsl:when>
            <xsl:when test=". = '2897'">Macedonia, the former Yugoslav Republic of </xsl:when>
            <xsl:when test=". = '2898'">Madagascar </xsl:when>
            <xsl:when test=". = '2899'">Malawi </xsl:when>
            <xsl:when test=". = '2900'">Malaysia </xsl:when>
            <xsl:when test=". = '2901'">Maldives </xsl:when>
            <xsl:when test=". = '2902'">Mali </xsl:when>
            <xsl:when test=". = '1048'">Malta </xsl:when>
            <xsl:when test=". = '2904'">Marshall Islands </xsl:when>
            <xsl:when test=". = '2905'">Martinique </xsl:when>
            <xsl:when test=". = '2908'">Mauritania </xsl:when>
            <xsl:when test=". = '2909'">Mauritius </xsl:when>
            <xsl:when test=". = '2910'">Mayotte </xsl:when>
            <xsl:when test=". = '1067'">Mexico </xsl:when>
            <xsl:when test=". = '3877'">Micronesia, Federated States of </xsl:when>
            <xsl:when test=". = '2919'">Moldova, Republic of </xsl:when>
            <xsl:when test=". = '2921'">Monaco </xsl:when>
            <xsl:when test=". = '2922'">Mongolia </xsl:when>
            <xsl:when test=". = '7821'">Montenegro </xsl:when>
            <xsl:when test=". = '2924'">Montserrat </xsl:when>
            <xsl:when test=". = '2925'">Morocco </xsl:when>
            <xsl:when test=". = '2926'">Mozambique </xsl:when>
            <xsl:when test=". = '2930'">Myanmar </xsl:when>
            <xsl:when test=". = '2932'">Namibia </xsl:when>
            <xsl:when test=". = '2933'">Nauru </xsl:when>
            <xsl:when test=". = '2934'">Nepal </xsl:when>
            <xsl:when test=". = '1158'">Netherlands </xsl:when>
            <xsl:when test=". = '2935'">Netherlands Antilles </xsl:when>
            <xsl:when test=". = '2938'">New Caledonia </xsl:when>
            <xsl:when test=". = '1161'">New Zealand </xsl:when>
            <xsl:when test=". = '2939'">Nicaragua </xsl:when>
            <xsl:when test=". = '2940'">Niger </xsl:when>
            <xsl:when test=". = '2941'">Nigeria </xsl:when>
            <xsl:when test=". = '2942'">Niue </xsl:when>
            <xsl:when test=". = '2945'">Norfolk Island </xsl:when>
            <xsl:when test=". = '2946'">Northern Mariana Islands </xsl:when>
            <xsl:when test=". = '1175'">Norway </xsl:when>
            <xsl:when test=". = '2977'">Oman </xsl:when>
            <xsl:when test=". = '2984'">Pakistan </xsl:when>
            <xsl:when test=". = '2985'">Palau </xsl:when>
            <xsl:when test=". = '2986'">Palestinian Territory, occupied </xsl:when>
            <xsl:when test=". = '2987'">Panama </xsl:when>
            <xsl:when test=". = '2988'">Papua New Guinea </xsl:when>
            <xsl:when test=". = '2989'">Paraguay </xsl:when>
            <xsl:when test=". = '2994'">Peru </xsl:when>
            <xsl:when test=". = '2995'">Philippines </xsl:when>
            <xsl:when test=". = '3000'">Pitcairn </xsl:when>
            <xsl:when test=". = '1394'">Poland </xsl:when>
            <xsl:when test=". = '1401'">Portugal </xsl:when>
            <xsl:when test=". = '3027'">Puerto Rico </xsl:when>
            <xsl:when test=". = '3028'">Qatar </xsl:when>
            <xsl:when test=". = '1496'">Romania </xsl:when>
            <xsl:when test=". = '3177'">Réunion </xsl:when>
            <xsl:when test=". = '3175'">Russian Federation </xsl:when>
            <xsl:when test=". = '3176'">Rwanda </xsl:when>
            <xsl:when test=". = '7823'">Saint Barthélemy </xsl:when>
            <xsl:when test=". = '3318'">Saint Helena </xsl:when>
            <xsl:when test=". = '3319'">Saint Kitts and Nevis </xsl:when>
            <xsl:when test=". = '3320'">Saint Lucia </xsl:when>
            <xsl:when test=". = '7824'">Saint Martin </xsl:when>
            <xsl:when test=". = '3321'">Saint Pierre and Miquelon </xsl:when>
            <xsl:when test=". = '3322'">Saint Vincent and the Grenadines </xsl:when>
            <xsl:when test=". = '3323'">Samoa </xsl:when>
            <xsl:when test=". = '3324'">San Marino </xsl:when>
            <xsl:when test=". = '3325'">Sao Tome and Principe </xsl:when>
            <xsl:when test=". = '3326'">Saudi Arabia </xsl:when>
            <xsl:when test=". = '3328'">Senegal </xsl:when>
            <xsl:when test=". = '3332'">Serbia </xsl:when>
            <xsl:when test=". = '3333'">Seychelles </xsl:when>
            <xsl:when test=". = '3336'">Sierra Leone </xsl:when>
            <xsl:when test=". = '3337'">Singapore </xsl:when>
            <xsl:when test=". = '3339'">Slovakia </xsl:when>
            <xsl:when test=". = '1562'">Slovenia </xsl:when>
            <xsl:when test=". = '3340'">Solomon Islands </xsl:when>
            <xsl:when test=". = '3343'">Somalia </xsl:when>
            <xsl:when test=". = '3344'">South Africa </xsl:when>
            <xsl:when test=". = '3345'">South Georgia and the South Sandwich Islands </xsl:when>
            <xsl:when test=". = '1567'">Spain </xsl:when>
            <xsl:when test=". = '3346'">Sri Lanka </xsl:when>
            <xsl:when test=". = '3352'">Sudan </xsl:when>
            <xsl:when test=". = '3355'">Suriname </xsl:when>
            <xsl:when test=". = '3357'">Svalbard and Jan Mayen </xsl:when>
            <xsl:when test=". = '3358'">Swaziland </xsl:when>
            <xsl:when test=". = '1591'">Sweden </xsl:when>
            <xsl:when test=". = '1595'">Switzerland </xsl:when>
            <xsl:when test=". = '3359'">Syrian Arab Republic </xsl:when>
            <xsl:when test=". = '3362'">Taiwan, Province of China </xsl:when>
            <xsl:when test=". = '3363'">Tajikistan </xsl:when>
            <xsl:when test=". = '3364'">Tanzania, United Republic of </xsl:when>
            <xsl:when test=". = '3366'">Thailand </xsl:when>
            <xsl:when test=". = '3370'">Timor-Leste </xsl:when>
            <xsl:when test=". = '3371'">Togo </xsl:when>
            <xsl:when test=". = '3372'">Tokelau </xsl:when>
            <xsl:when test=". = '3373'">Tonga </xsl:when>
            <xsl:when test=". = '3393'">Trinidad and Tobago </xsl:when>
            <xsl:when test=". = '3394'">Tunisia </xsl:when>
            <xsl:when test=". = '1641'">Turkey </xsl:when>
            <xsl:when test=". = '3395'">Turkmenistan </xsl:when>
            <xsl:when test=". = '3396'">Turks and Caicos Islands </xsl:when>
            <xsl:when test=". = '3397'">Tuvalu </xsl:when>
            <xsl:when test=". = '3402'">Uganda </xsl:when>
            <xsl:when test=". = '3403'">Ukraine </xsl:when>
            <xsl:when test=". = '3406'">United Arab Emirates </xsl:when>
            <xsl:when test=". = '1651'">United Kingdom </xsl:when>
            <xsl:when test=". = '1652'">United States </xsl:when>
            <xsl:when test=". = '3407'">United States Minor Outlying Islands </xsl:when>
            <xsl:when test=". = '3410'">Uruguay </xsl:when>
            <xsl:when test=". = '3412'">Uzbekistan </xsl:when>
            <xsl:when test=". = '3414'">Vanuatu </xsl:when>
            <xsl:when test=". = '3416'">Venezuela, Bolivarian Republic of </xsl:when>
            <xsl:when test=". = '3420'">Viet Nam </xsl:when>
            <xsl:when test=". = '3421'">Virgin Islands, British </xsl:when>
            <xsl:when test=". = '3422'">Virgin Islands, U.S. </xsl:when>
            <xsl:when test=". = '3425'">Wallis And Futuna </xsl:when>
            <xsl:when test=". = '3428'">Western Sahara </xsl:when>
            <xsl:when test=". = '3433'">Yemen </xsl:when>
            <xsl:when test=". = '3434'">Zambia </xsl:when>
            <xsl:when test=". = '3435'">Zimbabwe </xsl:when>
            <xsl:when test=". = '1342'">other: </xsl:when>
            <xsl:when test=". = '2207'">not specified </xsl:when>
            <xsl:when test=". = '1173'">no data </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="//xt:DataProtection/i6:confidentiality">
        <xsl:choose>
            <xsl:when test=". = '2732'">CBI </xsl:when>
            <xsl:when test=". = '2859'">IP </xsl:when>
            <xsl:when test=". = '3441'">no PA </xsl:when>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
